2D Geometry
===================


.. contents::
    :depth: 2
    :local:

.. currentmodule:: cr.nimble

Points and Vectors
----------------------------

.. autosummary::
    :toctree: _autosummary

    point2d
    vec2d

Transformations
--------------------

.. autosummary::
    :toctree: _autosummary

    rotate2d_cw
    rotate2d_ccw
    reflect2d
